/**
 * Copyright Watheia Labs, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from "react"
import NProgress from "nprogress"
import { useRouter } from "next/router"
import { useEffect } from "react"

export default function Progress() {
  const router = useRouter()

  useEffect(() => {
    let timeout: NodeJS.Timeout

    const start = () => {
      timeout = setTimeout(NProgress.start, 100)
    }

    const done = () => {
      clearTimeout(timeout)
      NProgress.done()
    }

    if (router) {
      router.events.on("routeChangeStart", start)
      router.events.on("routeChangeComplete", done)
      router.events.on("routeChangeError", done)
    }
    return () => {
      if (router) {
        router.events.off("routeChangeStart", start)
        router.events.off("routeChangeComplete", done)
        router.events.off("routeChangeError", done)
      }
    }
  }, [])
  return <></>
}
